@@ -334,8 +334,6 @@ class WacomKnowledgeService(WacomServiceAPIClient):
         response: Response = requests.post(url, json=payload, headers=headers, verify=self.verify_calls)
         if response.ok:
             uri: str = response.json()[URI_TAG]
-            if entity.image is not None and entity.image != '':
-                self.set_entity_image_url(auth_key, uri, entity.image)
             return uri
 
         import json
